@@ -1,6 +1,6 @@
 #' parseMatrixContent
 #'
-#' Parses character matrix content into a text vector. This is the basic function of 'tableParser', which is implemented in 'matrix2text()', 'table2text()', and 'table2stats()'. Row and column names are parsed to cell content with operators that depend on the cell content. Numeric cells are parsed with "=", and textual cell content with ":". Cells that start with an operator ('<', '=' or '>') are parsed without a separator. Detected codings for (e.g., p-values, abbreviations) from table legend text can be used to extend the tabled content to a fully written-out form.
+#' Parses character matrix content into a text vector. This is the basic function of 'tableParser', which is implemented in matrix2text(), table2text(), and table2stats(). Row and column names are parsed to cell content with operators that depend on the cell content. Numeric cells are parsed with "=", and textual cell content with ":". Cells that start with an operator ('<', '=' or '>') are parsed without a separator. Detected codings for (e.g., p-values, abbreviations) from table legend text can be used to extend the tabled content to a fully written-out form.
 #' @param x A character matrix or list with a character matrix as first and only element.
 #' @param legend The table's caption/footnote as a character vector.
 #' @param decodeP Logical. If TRUE, imputes the converts the detected p-value codings to text with seperator ';;' (e.g., '1.23*' -> '1.23;; p<.01')
@@ -8,9 +8,9 @@
 #' @param noSign2p Logical. If TRUE, imputes 'p>maximum of the detected p-value codes to cells that do have a coding sign.
 #' @param bracketHandling Logical. If TRUE and if possible, decodes numbers in brackets.
 #' @param forceClass Character. Set a fixed table class for extraction heuristic. One of c("tabled result", "correlation", "matrix", "text").
-#' @param expandAbbreviations Logical. If TRUE, detected abbreviations are expanded to label detected in table caption/footnotes with 'tableParser::legendCodings()'.
+#' @param expandAbbreviations Logical. If TRUE, detected abbreviations are expanded to label detected in table caption/footnotes with legendCodings().
 #' @param superscript2bracket Logical. If TRUE, detected superscript codings are inserted inside parentheses.
-#' @param dfHandling Logical. If TRUE, detected sample size N in the caption/footnotes is inserted as degrees of freedom (N-2) to r- and t-values that are reported without degrees of freedom. 
+#' @param dfHandling Logical. If TRUE, detected sample size N in the caption/footnotes is inserted as degrees of freedom (N-2) to r- and t-values that are reported without degrees of freedom, if the detected N>3. 
 #' @returns A text vector with the parsed matrix content.
 #' @examples
 #' # Example matrix
@@ -99,16 +99,18 @@ parseMatrixContent<-function(x,legend=NULL,
     x<-parseContent(x)
     # add degrees of freedom
     if(isTRUE(dfHandling)){
-      # add df=max(n)-2 for t and r values if has N= in legend
-      if(!is.null(N)){
+      # add df=max(n)-2 for t and r values if has N>3 in legend
+      if(length(N)>0){
         # get highest N
         maxN<-suppressWarnings(max(suppressWarnings(as.numeric(gsub(".*[<=>]","",N))),na.rm=T))
         # add maxN-2 to r= and t= if no df is found
         i<-(grep(" df[12]*=|degrees* of freed",x,invert=TRUE))
+        maxN<-maxN[maxN>3]
+        if(length(maxN)>0){
         if(maxN!=-Inf) x[i]<-gsub(" r=",paste0(" r(",maxN-2,")="),x[i])
         if(maxN!=-Inf) x[i]<-gsub(" t=",paste0(" t(",maxN-2,")="),x[i])
-        if(maxN!=-Inf) x[i]<-gsub(" T=",paste0(" T(",maxN-2,")="),x[i])
-      }
+        #if(maxN!=-Inf) x[i]<-gsub(" T=",paste0(" T(",maxN-2,")="),x[i])
+      }}
     }
     return(x)
   } 
@@ -130,12 +132,10 @@ parseMatrixContent<-function(x,legend=NULL,
     }
   }
   
-  
   # convert Cronbachs alpha values
   if(length(alpha)>0)
     m<-enter.CrAlpha(m,alpha)
   
-  
   # remove empty lines/cols
   #row.rm<-which(rowSums(m=="",na.rm=TRUE)==ncol(m))
   #col.rm<-which(colSums(m=="",na.rm=TRUE)==nrow(m))
@@ -153,7 +153,7 @@ parseMatrixContent<-function(x,legend=NULL,
   if(is.null(forceClass)) class<-tableClass(m,legend=legend)
   
   # return parsed vector 
-  if(tableClass(m)=="vector"){
+  if(class=="vector"){
     m<-parseContent(m)
     # add degrees of freedom
     if(isTRUE(dfHandling)){
@@ -171,16 +171,12 @@ parseMatrixContent<-function(x,legend=NULL,
     return(m) 
   }
   
-  ########################################
-  # remove lines with no values in cor matrices
-#  if(class=="correlation"){
-#    i<-(rowSums(m[,]=="")!=(ncol(m)-1)&!grepl("^[1-9]",m[,1]))
-#    m<-m[i,]
-#  }
-  
+
   # remove categorizing lines in correlation table
-  if(class=="correlation"){ 
-    if(nrow(m)>2&ncol(m)>2){
+  if(class=="correlation"|class=="matrix"){ 
+    m<-coding2variable(m)
+    if(nrow(m)>2&ncol(m)>2&
+       nrow(m)!=ncol(m)){
       i<-which(rowSums(m[-1,-1]=="")==(ncol(m)-1)&!grepl("^[1-9]",m[-1,1]))
       if(length(i)>0) m<-m[-(i+1),]
     }
@@ -200,6 +196,7 @@ parseMatrixContent<-function(x,legend=NULL,
    }
   }
   
+  
   if(class!="text"&class!="vector"){
     # create new columns for brackets and percent
     if(isTRUE(bracketHandling)){
@@ -241,29 +238,32 @@ parseMatrixContent<-function(x,legend=NULL,
     pval<-c("p<.001","p<.01","p<.05")
   }
   
-  # decode p values in inner matrix
+  # decode p values 
   if(isTRUE(decodeP)){
   if(length(pval)>0) 
-    m[-1,-1]<-sign2p(m[-1,-1],psign,pval,sep=";;")
+    # full matrix
+    m<-sign2p(m,psign,pval,sep=";;")
+  
+  # only in inner matrix
+  #m[-1,-1]<-sign2p(m[-1,-1],psign,pval,sep=";;")
   
   # convert p stars in outer matrix with result^**
-  if(length(pval)>0) {
-    # first column
-    i<-grep("[A-z]\\^*2* *[<=>][<=>]* *-*[\\.0-9][\\.0-9]*\\^*\\*",m[,1])
-    if(length(i)>0) m[i,1]<-sign2p(m[i,1],psign,pval,sep=";;")
-    # first row
-    i<-grep("[A-z]\\^*2* *[<=>][<=>]* *-*[\\.0-9][\\.0-9]*\\^*\\*",m[1,])
-    if(length(i)>0) m[1,i]<-sign2p(m[1,i],psign,pval,sep=";;")
-    }
-
-  } # end
+  #if(length(pval)>0) {
+  #  # first column
+  #  i<-grep("[A-z]\\^*2* *[<=>][<=>]* *-*[\\.0-9][\\.0-9]*\\^*\\*",m[,1])
+  #  if(length(i)>0) m[i,1]<-sign2p(m[i,1],psign,pval,sep=";;")
+  #  # first row
+  #  i<-grep("[A-z]\\^*2* *[<=>][<=>]* *-*[\\.0-9][\\.0-9]*\\^*\\*",m[1,])
+  #  if(length(i)>0) m[1,i]<-sign2p(m[1,i],psign,pval,sep=";;")
+  #  }
   
-  # remove superscripted bold and italic text
+  # remove all other superscripted bold and italic text
   m<-gsub("\\^italic","",m)
   m<-gsub("\\^bold","",m)
+  }
 
   # convert abbreviations in first row and col
-  if(expandAbbreviations=="TRUE"){
+  if(isTRUE(expandAbbreviations)){
     if(is.matrix(m)){
       m[1,]<-abb2text(m[1,],abbr=abbr,label=label)
       m[,1]<-abb2text(m[,1],abbr=abbr,label=label)
@@ -311,8 +311,6 @@ parseMatrixContent<-function(x,legend=NULL,
         if(maxN!=-Inf) m[i]<-gsub(" T=",paste0(" T(",maxN-2,")="),m[i])
       }
     }
-  
-    
     return(m)
     } 
   
@@ -367,7 +365,6 @@ parseMatrixContent<-function(x,legend=NULL,
   }
 } # results are in updated "m" and object "correlations"
 
-  
   # if first cell contains result create new line and move result to first cell in new line
   if(is.matrix(m)) {
     if(nrow(m)>2){
@@ -378,7 +375,6 @@ parseMatrixContent<-function(x,legend=NULL,
       }}
   }
   
-  
   i<-NULL;j<-NULL
   if(length(m)>0&is.matrix(m)){
   # convert ns -> p>.05
@@ -409,7 +405,7 @@ parseMatrixContent<-function(x,legend=NULL,
   #if(sum(j)>0) m[i,][j,]<-noSign2p(m[i,][j,],pval=pval)
   
   # expand detected superscripts
-  if(superscript2bracket=="TRUE"){
+  if(isTRUE(superscript2bracket)){
     if(is.matrix(m)){
       m<-sup2text(m,sup=sup,sup_label=sup_label)
     }
