@@ -135,7 +135,9 @@ multiHeaderSplit<-function(x,split=FALSE,class=NULL){
   at<-NULL
  if(length(nrow(x))>0){
  if(ncol(x)<2) return(x)
-  # detect lines with only the same value
+ if(ncol(x)==nrow(x) & class == "correlation") return(x)
+ if(ncol(x)==(nrow(x)-1) & class == "correlation") return(x)
+   # detect lines with only the same value
   for(i in 1:nrow(x)) at[i]<-sum(x[i,]==x[i,1])==length(x[i,])
   # and remove those that are also part in col names
   # only proceed if has line to split at
@@ -194,9 +196,6 @@ multiHeaderSplit<-function(x,split=FALSE,class=NULL){
     for(k in 1:(length(at)-1))
       at[k+1]<-ifelse(isTRUE(at[k])&isTRUE(at[k+1]),FALSE,at[k+1])
   }
-  at
-  
-  
   
   # paste first cell to lines below
   if(sum(at>0)){
@@ -217,10 +216,8 @@ multiHeaderSplit<-function(x,split=FALSE,class=NULL){
    }
  }
   return(x)
-
 }
 
-
 ## function to unify textual output
 unifyOutput<-function(x){
   # unify minus/hyphen sign
@@ -464,15 +461,20 @@ colHandling<-function(m){
 
 ## convert numeric codings of variables in correlation matrices
 coding2variable<-function(m){
+  
+  # remove brackets around enumeration
+  m[1,]<-gsub("^\\(([0-9][0-9]*\\.*)\\)","\\1",m[1,])
+  m[,1]<-gsub("^\\(([0-9][0-9]*\\.*)\\)","\\1",m[,1])
+  # move number in brackets at end to front
+  m[1,]<-gsub("(.*) \\(([0-9][0-9]*\\.*)\\)$","\\2 \\1",m[1,])
+  m[,1]<-gsub("(.*) \\(([0-9][0-9]*\\.*)\\)$","\\2 \\1",m[,1])
+  
+  # remove bold/italic from first row and col, and stars and coded p-values at end behind letter
+  m[1,]<-gsub("\\^bold|\\^italic|([A-z]) *\\^*\\*\\**","\\1",m[1,])
+  m[,1]<-gsub("\\^bold|\\^italic|([A-z]) *\\^*\\*\\**","\\1",m[,1])
+  m
   # if coding is in first row
   if(sum(nchar(m[1,]),na.rm=TRUE)>sum(nchar(m[,1]),na.rm=TRUE)){
-    # remove brackets around enumeration
-    m[1,]<-gsub("^\\(([0-9][0-9]*\\.*)\\)","\\1",m[1,])
-    m[,1]<-gsub("^\\(([0-9][0-9]*\\.*)\\)","\\1",m[,1])
-    # move number in brackets at end to front
-    m[1,]<-gsub("(.*) \\(([0-9][0-9]*\\.*)\\)$","\\2 \\1",m[1,])
-    m[,1]<-gsub("(.*) \\(([0-9][0-9]*\\.*)\\)$","\\2 \\1",m[,1])
-    m
     fullNames<-m[1,] 
     # get numeric coding and varNames
     coding<-gsub("^([0-9][0-9]*).*|^[^:]*: ([0-9][0-9]*).*","\\1\\2",fullNames)
@@ -494,15 +496,27 @@ coding2variable<-function(m){
     }
   }
   
-  
   # if coding is in first column
   if(sum(nchar(m[1,]),na.rm=TRUE)<sum(nchar(m[,1]),na.rm=TRUE)){
-    # remove brackets around enumeration
-    m[1,]<-gsub("^\\(([0-9][0-9]*\\.*)\\)","\\1",m[1,])
-    m[,1]<-gsub("^\\(([0-9][0-9]*\\.*)\\)","\\1",m[,1])
     
-    fullNames<-m[,1] 
+    # add numbers from first row to first column if has no numbers
+    # and matrix is quadratic
+    if(length(m[1,])==length(m[,1]) & 
+       length(grep("^[1-9]",m[,1]))==0 &
+       length(grep("^[1-9][0-9]*\\.*$",m[1,]))==(ncol(m)-1)
+    )
+      m[-1,1] <-  paste0(gsub("\\.","",m[1,-1]),". ",m[-1,1])
+    
+    # if nrow-1==ncol
+    if(ncol(m)==(nrow(m)-1) & 
+       length(grep("^[1-9]",m[,1]))==0 &
+       grepl("^$|^1[\\.0]*$",m[2,2]) &
+       length(grep("^[1-9][0-9]*\\.*$",m[1,]))==(ncol(m)-1)
+    )
+      m[-1,1]<-paste0(gsub("\\.","",m[1,-1][1]:(nrow(m)-1)),". ",m[-1,1])
+      
     # get numeric coding and varNames
+    fullNames<-m[,1] 
     coding<-gsub("^([0-9][0-9]*).*|^[^:]*: ([0-9][0-9]*).*","\\1\\2",fullNames)
     coding[grep("^[0-9]",coding,invert=TRUE)]<-""
     varNames<-gsub("^[0-9][^A-z]*([A-z])|^[^:]*: [0-9][^A-z]*([A-z])","\\1\\2",fullNames)
@@ -514,22 +528,23 @@ coding2variable<-function(m){
     
     if((sum(is.element(c(1,2,3),gsub("^0","",coding)))==3|sum(is.element(c(2,3,4),gsub("^0","",coding)))==3) &
        sum(nchar(coding))!=0){
-      for(i in 1:length(coding)){
-        colname<-gsub(paste0("^",coding[i],"[^0-9]*$"),codes[i],colname)
-      }
+          for(i in 1:length(coding)) colname<-gsub(paste0("^",coding[i],"[^0-9]*$"),codes[i],colname)
+      # override names
       m[1,]<-colname
       m[,1]<-varNames  
     }
   } 
-
+  
   # if first row still contains numbers and nrow=ncol
   if(sum(is.element(c(1,2,3),gsub("^0","",m[1,])))==3){
     if(nrow(m)==ncol(m))
       m[1,]<-m[,1]
   }
   
+  # add space between letter-bracket-letters
+  m<-gsub("([A-z])(\\([A-z][-A-z _]*\\))","\\1 \\2",m)
+  
   
-      
 return(m)
 }# end function coding2variable
 
@@ -715,8 +730,8 @@ extractCorrelations<-function(x,
   # insert diaginal statistic instead of r=
   if(length(diagonal)>0){
     x<-gsub("^(.*) <<~>>.*","\\1",correlations)
-    y<-gsub(".*<<~>> (.*): r=.*","\\1",correlations)
-    i<-which(x==y)
+    y<-gsub(".*<<~>> (.*): r[=\\(].*","\\1",correlations)
+    i<-which(tolower(x)==tolower(y))
     correlations[i]<-gsub("(<<~>>[^:]*: )r\\(*[0-9]*\\)*=",paste0("\\1",diagonal,"="),correlations[i])
     correlations[i]<-gsub(paste0("(",diagonal,"=-*[0-9\\.][0-9\\.]*);; p[<=>][<=>]*[0-9\\.]*"),"\\1",correlations[i])
   }
@@ -724,9 +739,9 @@ extractCorrelations<-function(x,
   
   
   # insert "alpha" for r if var x and y are the same and 0<r<1
-  x<-gsub("^(.*) <<~>>.*","\\1",correlations)
-  y<-gsub(".*<<~>> (.*): r=.*","\\1",correlations)
-  i<-which(x==y)
+  x<-gsub("^(.*)<<~>>.*","\\1",correlations)
+  y<-gsub(".*<<~>>(.*): r[=\\(].*","\\1",correlations)
+  i<-which(tolower(x)==tolower(y))
   correlations[i]<-gsub("(<<~>>[^:]*: )r\\(*[0-9]*\\)*=([0\\.])",paste0("\\1alpha=\\2"),correlations[i])
   
   # remove p values behind alpha
@@ -741,7 +756,8 @@ extractCorrelations<-function(x,
   correlations[i]<-gsub("alpha(=[0-9\\.][0-9\\.]*)[ ,;].*sqrt *AVE*.*","sqrt AVE\\1",correlations[i])
   correlations[i]<-gsub("alpha(=[0-9\\.][0-9\\.]*)[ ,;].*AVE.*|alpha(=[0-9\\.][0-9\\.]*) .*[ \\(]AVE\\)*.*","AVE\\1\\2",correlations[i])
   
-  # add (Nmax-2) to r=
+  # add (Nmax-2) to "r=" if Nmax>1
+  N<-N[N>1]
   if(length(N)>0){
     Nmax<-suppressWarnings(max(as.numeric(N),na.rm=T))
     if(!is.na(Nmax)){
@@ -867,8 +883,8 @@ extractMatrix<-function(x,
     rem[,cols]<-FALSE
   }
   # set rows/cols with mean/sd/etc to FALSE
-  values[grep("eta\\^*2|omega\\^2|^rho\\^*2*$|^ICC|intraclass correlation|Cronbach|^[Mm]ean$| [Mm]eans*$|^M$|[Ss]tandard [Dd]eviation|^SD[Ss]*$| SD[Ss]*$|^[aA]lpha$| [aA]lpha$|^CR |^CR$|^AVE[^A-z]|[^A-z]AVES*$|^AVE$|^MSV$|^ASV$|Skewnes|[KC]urtosis|[Rr]eliabilit|^[Vv]ariance| [Vv]ariance|[sS]quared",m[,1]),-1]<-FALSE
-  values[-1,grep("eta\\^*2|omega\\^2|^rho\\^*2*$|^ICC|intraclass correlation|Cronbach|^[Mm]ean$| [Mm]eans*$|^M$|[Ss]tandard [Dd]eviation|^SD[Ss]*$| SD[Ss]*$|^[aA]lpha$| [aA]lpha$|^CR |^CR$|^AVE[^A-z]|[^A-z]AVES*$|^AVE$|^MSV|^ASV$$|Skewnes|[KC]urtosis|[Rr]eliabilit|^[Vv]ariance| [Vv]ariance|[sS]quared",m[1,])]<-FALSE
+  values[grep("^[n]$|eta\\^*2|omega\\^2|^rho\\^*2*$|^ICC|intraclass correlation|Cronbach|^[Mm]ean$| [Mm]eans*$|^M$|[Ss]tandard [Dd]eviation|^SD[Ss]*$| SD[Ss]*$|^[aA]lpha$| [aA]lpha$|^CR |^CR$|^AVE[^A-z]|[^A-z]AVES*$|^AVE$|^MSV$|^ASV$|Skewnes|[KC]urtosis|[Rr]eliabilit|^[Vv]ariance| [Vv]ariance|[sS]quared",m[,1]),-1]<-FALSE
+  values[-1,grep("^[n]$|eta\\^*2|omega\\^2|^rho\\^*2*$|^ICC|intraclass correlation|Cronbach|^[Mm]ean$| [Mm]eans*$|^M$|[Ss]tandard [Dd]eviation|^SD[Ss]*$| SD[Ss]*$|^[aA]lpha$| [aA]lpha$|^CR |^CR$|^AVE[^A-z]|[^A-z]AVES*$|^AVE$|^MSV|^ASV$$|Skewnes|[KC]urtosis|[Rr]eliabilit|^[Vv]ariance| [Vv]ariance|[sS]quared",m[1,])]<-FALSE
   
   # convert numbered variable name to full name label 
   m<-coding2variable(m)  
@@ -998,19 +1014,24 @@ sign2p<-function(x,sign,val,sep=";;"){
   # special sign handling (replaces * to \\*)
   sign<-specialChars(sign)
 
+    # convert sign to pval if at end behind number or bracket
   for(i in 1:length(sign)){
-    #convert sign to pval if at end 
-    x<-gsub(paste0("\\^*",sign[i],"$"),
-             # p value with seperator     
-             paste(sep,val[i]),gsub("^n\\.*s\\.*$|( )n\\.*s\\.*$","\\1ns",x))
+    # if has no letter-num-sign
+    incl<-!grepl(paste0("[A-z][-_]*[0-9][0-9]*",sign[i]),x)
+    x[incl]<-gsub(paste0("[0-9\\)\\]] *\\^*",sign[i],"$"),
+             # replace with p value with seperator     
+             paste(sep,val[i]),gsub("^n\\.*s\\.*$|( )n\\.*s\\.*$","\\1ns",x[incl]))
     # convert sign to pval if NOT at end 
-    incl<-grep(paste0(". *",sign[i]," *[^0-9]"),x)#,invert=TRUE)
-    x[incl]<-gsub(paste0("\\^*",sign[i],"[,; ]*"),
+#    incl<-grepl(paste0(". *",sign[i]," *[^0-9]"),x))
+    # and not between a pair of letters or pair of numbers
+    incl<-incl & !grepl(paste0("[A-z] *\\^*",sign[i]," *[\\(\\[A-z]",
+                       "|[0-9] *\\^*",sign[i]," *[0-9]"),x)
+    x[incl]<-gsub(paste0(" *\\^*",sign[i],"[,; ]*"),
             # p value with seperator     
             paste0(sep," ",val[i],", "),x[incl])
     
     # clean up if cell has ^;; p-val
-    x<-gsub(paste0("\\^(",sep," )"),"\\1",x)
+    x<-gsub(paste0(" *\\^(",sep," )"),"\\1",x)
     # clean up if cell starts with seperator
 #    x<-gsub(paste0("^",sep," "),"",x)
     # clean up before bracket
@@ -1019,6 +1040,8 @@ sign2p<-function(x,sign,val,sep=";;"){
   }
   
   x<-gsub(": ;;",";;",x)
+  x<-gsub("[,;] $","",x)
+  
   return(x)
 }
 
@@ -1032,28 +1055,67 @@ noSign2p<-function(x,pval){
   if(length(pval)==0) return(x)
   nCol<-ncol(x)
   # find cloumns with already inserted p-values and no results in front
-  cols<-which(colSums(matrix(grepl(";; p<",x) & 
-                               !grepl("[A-z]\\^*2* *[<=>][<=>]* *-*[0-9\\.]*[0-9\\.];; p<",x),ncol=nCol))>0)
+  cols<-which(colSums(matrix(grepl(";; p<",x),ncol=nCol))>0)
   # escape
   if(length(cols)==0) return(x)
   # get max of coded p
   if(length(pval)>0) Pmax<-max(as.numeric(gsub("p<=*","",pval)))
-  if(length(pval)==0) Pmax<-max(as.numeric(gsub("^(0*.*[0-9][0-9]*).*","\\1",gsub(".*;; p<=*","",grep(";; p<",x[,cols],value=TRUE)))))
-  # go through columns and add p>Pmax in without ;; p>
+  if(length(pval)==0) Pmax<-max(as.numeric(gsub("^(0*.*[0-9][0-9]*).*","\\1",
+                                                gsub(".*;; p<=*","",grep(";; p<",x[,cols],value=TRUE)))))
+  
+  ## find cloumns with already inserted p-values and only number in front
+  cols<-which(colSums(matrix(grepl("^[<=>]*-*[\\.0-9][\\.0-9]*;; p<",x),ncol=nCol))>0)
+
+  # go through columns and add p>Pmax in cells without ;; p>
+  if(length(cols)>0)
   for(j in cols){
-    cells<-!grepl(";; p<|;; p>",x[,j])
-    # set first cell to FALSE 
-    cells[1]<-FALSE
-    # exclude empty cells if has number-coded p 
-    if(sum(grepl("[0-9];; p",x[-1,j]))>0)
-    cells[x[,j]==""]<-FALSE
-    
+    cells<-!grepl(";; p<|;; p>",x[,j]) & !grepl("^$",x[,j])&
+               grepl("^[<=>]*-*[\\.0-9][\\.0-9]*$",x[,j])
     # impute p>max(p<num)
     x[cells,j]<-gsub("([0-9])$",paste0("\\1;; p>",Pmax),x[cells,j])
-    if(j>1)
-    x[cells,j][grepl("[0-9]$",x[cells,j-1])]<-gsub("^$",paste0(";; p>",Pmax),x[cells,j][grepl("[0-9]$",x[cells,j-1])])
+    if(j>1)  x[cells,j][grepl("[0-9]$",x[cells,j-1])] <- 
+               gsub("^$",paste0(";; p>",Pmax),x[cells,j][grepl("[0-9]$",x[cells,j-1])])
   }
-  return(x)
+  
+  ## find cloumns with already inserted p-values and results in front
+  cols<-which(colSums(matrix(grepl("[A-z\\)]\\^*2* *[<=>][<=>]*-*[\\.0-9][\\.0-9]*;; p<",x)|
+                             grepl("[\\.0-9] *[;-] *-*[\\.0-9][\\.0-9]*[\\]\\)]*;; p<",x)
+                             ,ncol=nCol))>0)
+  
+  # go through columns and add p>Pmax in cells without ;; p>
+  if(length(cols)>0)
+    for(j in cols){
+      cells<-!grepl(";; p<|;; p>",x[,j]) & !grepl("^$",x[,j])&
+        (grepl("[A-z\\)]\\^*2* *[<=>][<=>]*-*[\\.0-9][\\.0-9]*$",x[,j])|
+           grepl("[\\.0-9] *[;-] *-*[\\.0-9][\\.0-9]*$",x[,j])|
+           grepl("[\\.0-9] *[;-] *-*[\\.0-9][\\.0-9]*\\)*\\]*$",x[,j])
+        )
+      # set first cell to FALSE 
+      #cells[1]<-FALSE
+      # impute p>max(p<num)
+      x[cells,j]<-gsub("([0-9]\\]*\\)*)$",paste0("\\1;; p>",Pmax),x[cells,j])
+      if(j>1)  x[cells,j][grepl("[0-9]\\]*\\)*$",x[cells,j-1])] <- 
+        gsub("^$",paste0(";; p>",Pmax),x[cells,j][grepl("[0-9]\\]*\\)*$",x[cells,j-1])])
+    }
+  
+  ## find cloumns with already inserted p-values and nothing in front
+  cols<-which(colSums(matrix(grepl("^;; p<",x)
+                             ,ncol=nCol))>0)
+  
+  # go through columns and add p>Pmax in without ;; p>
+  if(length(cols)>0)
+    for(j in cols){
+      cells<-!grepl("^;; p<|^;; p>",x[,j]) &
+                 grepl("^$",x[,j])
+      # set first cell to FALSE 
+      #cells[1]<-FALSE
+      # impute p>max(p<num)
+      x[cells,j]<-paste0(";; p>",Pmax)
+      if(j>1)  x[cells,j][grepl("[0-9]$",x[cells,j-1])] <- 
+        gsub("^$",paste0(";; p>",Pmax),x[cells,j][grepl("[0-9]$",x[cells,j-1])])
+    }
+
+    return(x)
 }
 
 # convert brackets to values
@@ -1094,7 +1156,8 @@ abb2text<-function(x,abbr,label){
   abbr<-abbr[i]
   label<-label[i]
   abbr<-specialChars(abbr)
-  
+  abbr<-gsub(" "," *",abbr)
+  abbr<-gsub("(\\.)([A-Z])","\\1 *\\2",abbr)
   # expand each abbreviation
   for(i in 1:length(abbr))  
     x<-gsub(
@@ -1181,49 +1244,82 @@ splitLastStat<-function(x){
       # define functions
       # split at last detected stat
       fun1<-function(x){
-      lastStat<-gsub(".*,[^<=>]* ([-A-z0-9\\^_][-A-z0-9\\^_]*)[<=>][<=>]*-*[0-9\\.][-0-9\\.\\^]*$","\\1",x)
-      # except coded p
+      lastStat<-gsub(".*, ([^<=>]* *[-A-z0-9\\^_][-A-z0-9\\^_]*)[<=>][<=>]*-*[0-9\\.][-0-9\\.\\^]*$","\\1",x)
+      # except lines with coded p at end
       lastStat[grep(";; p[<>=][<>=]*[0-9\\.][0-9\\.]*$",x)]<-x
-      
       # remove till standard stat
       lastStat<-gsub(".* ([SstTzZpPQIHdbBF][DFEdfe]*)$","\\1",lastStat)
       lastStat<-gsub(".* ([Cce][ht][ai]\\^*2*)$","\\1",lastStat)
       lastStat<-gsub(".* (omega\\^*2*)$","\\1",lastStat)
-      lastStat<-gsub(".* (R\\^*2*)$","\\1",lastStat)
-  #    lastStat<-gsub("\\^","\\\\^",lastStat)
-  #    lastStat<-gsub(".*([^A-z])\\\\\\^","\\\\\\1\\\\^",lastStat)
-      
+      #lastStat<-gsub(".* (R\\^*2*)$","\\1",lastStat)
       if(lastStat!=x){
       x<-gsub(paste0("([^;][^;] ",specialChars(lastStat),"[<=>][<=>]*-*[0-9\\.]*)[,:]* "),"\\1SPLITHERE",x)
       x<-unlist(strsplit(x,"SPLITHERE"))
-      if(length(x)>2){
+      #if(length(x)>2){
         # add first cell content to front of new lines
         #  x[-1]<-paste0(gsub("^([^,]*), .*","\\1, ",x[1]),x[-1])
         # add stats in table num:
         #x[-1]<-paste0(gsub("^([^:]*): .*","\\1: ",x[1]),", ",x[-1])
-      }
+      #}
       }
       return(x)
       }
       
-      # split at last detected imputed p-value
+      # split at imputed p-value
       fun2<-function(x){
         lastPcode<-gsub(".*(;; p)[<=>][<=>]*[0-9\\.]*$","\\1",x)
       if(sum(lastPcode!=x)>0){
-        x<-gsub(paste0("(;; p[<=>][<=>]*[0-9\\.]*)[,;] "),"\\1SPLITHERE",x)
-        x<-unlist(strsplit(x,"SPLITHERE"))
-        # add first cell content to front of new lines
-#        if(length(x)>1)
-          #  x[-1]<-paste0(gsub("^([^,]*), .*","\\1, ",x[1]),x[-1])
-          # add stats in table num:
-#          x[-1]<-paste0(gsub("^([^,:]*)[:,] .*","\\1: ",x[1]),x[-1])
+        x<-gsub(paste0("(;; p[<=>][<=>]*[0-9\\.]*), "),"\\1SPLITHERE ",x)
+        # remove SPLIT if in front of SE=
+        x<-gsub("SPLITHERE([^,;<>=]* SE=)",",\\1",x)
+        x<-unlist(strsplit(x,"SPLITHERE "))
       }
     return(x)
       }
       
+      # split at stat in front of remaining coded p values
+      # in lines with and without "delta"-anything
+      fun3<-function(x){
+        lastStat<-gsub(".*,[^<=>]* ([-A-z0-9\\^_][-A-z0-9\\^_]*)[<=>][<=>]*-*[0-9\\.][-0-9\\.\\^]*;; p[<=>\\.0-9]*$","\\1",x)
+        # has delta
+        hasDelta<-grep("[ Dd]elta",lastStat)>0
+        if(isFALSE(hasDelta)){
+        # remove till standard stat
+        lastStat<-gsub(".* ([SstTzZpPQIHdbBF][DFEdfe]*[_01]*)$","\\1",lastStat)
+        lastStat<-gsub(".* ([Cce][ht][ai]\\^*2*)$","\\1",lastStat)
+        lastStat<-gsub(".* (omega\\^*2*)$","\\1",lastStat)
+        lastStat<-gsub(".* (R\\^*2*)$","\\1",lastStat)
+        # only standard stats
+        lastStat<-grep("^[SstTzZpPQIHdbBF][DFEdfe]*$|^[Cce][ht][ai]\\^*2*$|^omega\\^*2*$|^R\\^*2*$",lastStat,value=TRUE)
+        }
+        if(isTRUE(hasDelta)){
+          # remove till standard stat
+          lastStat<-gsub(".*([dD]elta[ -][SstTzZpPQIHdbBF][DFEdfe]*)$","\\1",lastStat)
+          lastStat<-gsub(".* ([dD]elta[ -][Cce][ht][ai]\\^*2*)$","\\1",lastStat)
+          lastStat<-gsub(".* ([dD]elta[ -]omega\\^*2*)$","\\1",lastStat)
+          lastStat<-gsub(".* ([dD]elta[ -]R\\^*2*)$","\\1",lastStat)
+          # only standard stats
+          lastStat<-grep("^[dD]elta[ -][SstTzZpPQIHdbBF][DFEdfe]*$|^[Cce][ht][ai]\\^*2*$|^omega\\^*2*$|^R\\^*2*$",lastStat,value=TRUE)
+        }
+        
+        
+        if(lastStat!=x){
+          x<-gsub(paste0("( ",specialChars(lastStat),"[<=>][<=>]*-*[0-9\\.][0-9\\.]*), "),"\\1SPLITHERE",x)
+          x<-unlist(strsplit(x,"SPLITHERE"))
+          #if(length(x)>2){
+            # add first cell content to front of new lines
+            #  x[-1]<-paste0(gsub("^([^,]*), .*","\\1, ",x[1]),x[-1])
+            # add stats in table num:
+            #x[-1]<-paste0(gsub("^([^:]*): .*","\\1: ",x[1]),", ",x[-1])
+          #}
+        }
+        return(x)
+      }
+      
       # apply function cell wise
       x<-unlist(lapply(x,fun1))
       x<-unlist(lapply(x,fun2))
+  #    x<-unlist(lapply(x,fun3))
       x<-gsub(": ,",":",x)
       return(x)
     }
@@ -1433,17 +1529,18 @@ R2handler<-function(x){
 anovaHandler<-function(x){
   if(length(x)==0) return(x)
   
-  # remove text behind "F-"
-  x<-gsub(" (F) *- *[A-z]*([<=>])"," \\1\\2",x)
-  
   # take a copy for later activation of warning message
   y<-x
+  # remove text behind "F-"
+  x<-gsub(" (F) *[-_] *[A-z]*([<=>])"," \\1\\2",x)
+  
   # add df2 in lines with F-values
-  if(sum(grepl(" F=",x)&grepl(" [dD]\\.*[fF]\\.*=",x))>0 & 
-     sum(!grepl(" F=",x)&grepl(" [dD]\\.*[Ff]\\.*=",x))>0){
-    # has F but no "total"
-    i<-which(grepl(" F=",x)&!grepl(" [Tt]otal[^a-z]|^[Tt]otal[^a-z]",x))
-    j<-which(grepl(" [dD]\\.*[Ff]\\.*=",x)&!grepl(" F=",x)&!grepl("[Tt]otal",x))
+  if(sum(grepl(" F[<=>]",x)&grepl(" [dD]\\.*[fF]\\.*=",x))>0 & 
+     sum(!grepl(" F[<=>]",x)&grepl(" [dD]\\.*[Ff]\\.*=",x))>0){
+    
+    # but no "total"
+    i<-which(grepl(" F[<=>]",x)&!grepl(" [Tt]otal[^a-z]|^[Tt]otal[^a-z]",x))
+    j<-which(grepl(" [dD]\\.*[Ff]\\.*=",x)&!grepl(" F[<=>]",x)&!grepl("[Tt]otal",x))
     if(length(j)>0&length(grep(" [dD]\\.*[Ff]\\.*=",x[j]))>0){
       x[i]<-gsub(" [dD]\\.*[Ff]\\.*="," df1=",x[i])
       x[j]<-gsub(" [dD]\\.*[Ff]\\.*="," df2=",x[j])
@@ -1483,7 +1580,7 @@ anovaHandler<-function(x){
   }
   y
   # in lines with F-values
-  i<-grep(" F=",x)
+  i<-grep(" F[<=>]",x)
   if(length(i)>0){
    # convert df1 and df2 in brackets to text
    x[i]<-gsub(" [dD]\\.*[Ff]\\.*: \\(([0-9][0-9\\.]*)[,;] ([0-9][0-9\\.]*)\\)"," df1=\\1, df2=\\2",x[i])
@@ -1494,7 +1591,12 @@ anovaHandler<-function(x){
   # unify df1 and df2 in text
   x<-gsub("(:[^:]*)[dD]\\.*[Ff]\\.*[=: ]*([0-9][0-9\\.]*)[,;] *([0-9][0-9\\.]*)","\\1df1=\\2, df2=\\3",x)
   x<-gsub("(,[^,]*)[dD]\\.*[Ff]\\.*[=: ]*([0-9][0-9\\.]*)[,;] *([0-9][0-9\\.]*)","\\1df1=\\2, df2=\\3",x)
-  
+
+  # remove df1 and df2 if both are the same
+  df1<-gsub(".*df1=([0-9][0-9\\.]*).*","\\1",x)
+  df2<-gsub(".*df2=([0-9][0-9\\.]*).*","\\1",x)
+  i<-which(df1==df2)
+  x[i]<-gsub("df1=([0-9][0-9\\.]*),.*df2=[0-9][0-9\\.]*","\\df=",x[i])
   return(x)
 }
 
@@ -1553,8 +1655,6 @@ firstSeq<-function(x){
   return(seq)
 }
 
-###########################################################
-
 
 #####################################
 
@@ -1592,13 +1692,22 @@ modelStatsHandler<-function(x){
     if(ncol(x)<3) return(x)
   
   ## for standard results
-  ind1<-grep("eta\\^2|omega\\^2|chi\\^2|^[tZprRbBd]$|^[RO]R$|^[Ss]\\.* *[EeDd]\\.* *$|^[SsDd]\\.*[FfEeDd]\\.*$|^.\\^2$",
+  ind1<-grep("eta\\^2|omega\\^2|chi\\^2|^[tZprRbBd]$|^[RO]R$|^[Ss]\\.* *[EeDd]\\.* *$|^[SsDd]\\.*[FfEeDd]\\.*$|^.\\^2$|^AIC|^BIC|^[cC]hi\\^2|^[dD]egrees* of freedom|^[Dd]\\.*[Ff]\\.*$",
              gsub(".*: |[- ]val*u*e*s*|[_-][A-z0-9\\*+-]*|[ *_]\\(.*\\)","",x[,1]))
   ## for model statistics
   ind2<-NULL
   if(length(grep("[Cc]onstant|[Ii]ntercept|[Mm]odel",x))>0|(length(grep("[Mm]odel",class(x)))>0)) 
-  ind2<-grep("^R2$|[- ]R2|^R2 |R\\^2|R[- ][Ss]q|AIC|BIC|[Ii]nformation [Cr]iter|chi\\^2|degrees* of freedom|^[Dd]\\.*[Ff]\\.*$|[Ll]ikelihood",
-             x[,1])
+  ind2<-which(grepl("^R\\^*2$|[- ]R\\^*2$|^R2 |R\\^2|^R[- ][Ss]q|^[Ll]ikelihood",
+             x[,1])  
+               # and that have less than 5 characters in first column
+               #nchar(x[,1])<5
+               # and that don't have results in that line
+               #rowSums(matrix(grepl("[A-z\\)][\\^2]* *[<=>][<=>]* *[\\.0-9]",x),ncol=ncol(x),byrow = TRUE))==0
+             )
+  
+  # if first hit is in second row -> reset ind2 to NULL
+  if(isTRUE(ind2==2)) ind2<-NULL
+  
   ## take all the last rows if first hit is in lower half of table
   if(length(ind2)>0) 
     if(min(ind2)>(nrow(x)/2)) ind2<-min(ind2):nrow(x)
